@@ -5,11 +5,11 @@ library(storr)
 path <- tempfile("storr_")
 st <- storr::storr_rds(path)
 
-## ------------------------------------------------------------------------
-dr <- storr::driver_rds(path)
+## ----eval=FALSE----------------------------------------------------------
+#  dr <- storr::driver_rds(path)
 
-## ------------------------------------------------------------------------
-st <- storr::storr(dr)
+## ----eval=FALSE----------------------------------------------------------
+#  st <- storr::storr(dr)
 
 ## ------------------------------------------------------------------------
 st$set("mykey", mtcars)
@@ -32,8 +32,17 @@ st$del("mykey")
 st$list()
 
 ## ------------------------------------------------------------------------
-st$list_hashes()
-head(st$get_value(digest::digest(mtcars)))
+h <- st$list_hashes()
+h
+
+## ------------------------------------------------------------------------
+st$hash_object(mtcars)
+
+## ------------------------------------------------------------------------
+head(st$get_value(h))
+
+## ------------------------------------------------------------------------
+st$exists_object(h)
 
 ## ------------------------------------------------------------------------
 del <- st$gc()
@@ -42,12 +51,47 @@ del
 st$list_hashes()
 
 ## ------------------------------------------------------------------------
-st$import(list(a=1, b=2))
+st$default_namespace
+
+## ------------------------------------------------------------------------
+st$list_namespaces()
+
+## ------------------------------------------------------------------------
+st$set("a", runif(5), namespace = "other_things")
+st$list_namespaces()
+
+## ------------------------------------------------------------------------
+st$list()
+st$list("other_things")
+
+## ----error = TRUE--------------------------------------------------------
+st$get("a")
+st$get("a", "other_things")
+
+## ------------------------------------------------------------------------
+st$mset(c("a", "b", "c"), list(1, 2, 3))
+st$get("a")
+
+## ------------------------------------------------------------------------
+st$mget(c("a", "b", "c"))
+
+## ------------------------------------------------------------------------
+st$mget("a")
+st$mget(character(0))
+
+## ------------------------------------------------------------------------
+st$mset("x", list("a", "b"), namespace = c("ns1", "ns2"))
+st$mget("x", c("ns1", "ns2"))
+
+st$mget(c("a", "b", "x"), c("objects", "objects", "ns1"))
+
+## ------------------------------------------------------------------------
+st$import(list(a = 1, b = 2))
 st$list()
 st$get("a")
 
 ## ------------------------------------------------------------------------
-e <- st$export(new.env(parent=emptyenv()))
+e <- st$export(new.env(parent = emptyenv()))
 ls(e)
 e$a
 
@@ -55,7 +99,7 @@ st_copy <- st$export(storr_environment())
 st_copy$list()
 st$get("a")
 
-st2 <- storr::storr(driver=storr::driver_rds(tempfile("storr_")))
+st2 <- storr::storr(driver = storr::driver_rds(tempfile("storr_")))
 st2$list()
 st2$import(st)
 st2$list()
@@ -72,7 +116,7 @@ st$list_hashes()
 dir(file.path(path, "data"))
 
 ## ------------------------------------------------------------------------
-st <- storr::storr(driver=storr::driver_rds(tempfile("storr_")))
+st <- storr::storr(driver = storr::driver_rds(tempfile("storr_")))
 
 ## ------------------------------------------------------------------------
 ls(st$envir)
@@ -85,7 +129,7 @@ st$set("mykey", runif(100))
 ls(st$envir)
 
 ## ------------------------------------------------------------------------
-storr:::hash_object(st$envir[[ls(st$envir)]])
+st$hash_object(st$envir[[ls(st$envir)]])
 
 ## ------------------------------------------------------------------------
 st$get_hash("mykey")
@@ -95,18 +139,21 @@ st$get_value
 
 ## ------------------------------------------------------------------------
 hash <- st$get_hash("mykey")
-microbenchmark::microbenchmark(st$get_value(hash, use_cache=TRUE),
-                               st$get_value(hash, use_cache=FALSE))
+if (requireNamespace("rbenchmark")) {
+  rbenchmark::benchmark(st$get_value(hash, use_cache = TRUE),
+                        st$get_value(hash, use_cache = FALSE),
+                        replications = 1000, order = NULL)[1:4]
+}
 
 ## ------------------------------------------------------------------------
 tryCatch(st$get("no_such_key"),
-         KeyError=function(e) NULL)
+         KeyError = function(e) NULL)
 
 ## ------------------------------------------------------------------------
 st$set("foo", letters)
 ok <- st$driver$del_object(st$get_hash("foo"))
 st$flush_cache()
 tryCatch(st$get("foo"),
-         KeyError=function(e) NULL,
-         HashError=function(e) message("Data is deleted"))
+         KeyError = function(e) NULL,
+         HashError = function(e) message("Data is deleted"))
 
